repling.agent.runtime

Runtime helper vars available to code evaluated by a live Repling agent.

These vars delegate through a dynamic live-agent binding, so generated tool files can use (require '[repling.agent.runtime :as rt]) and call helpers like rt/tool-register! or rt/tool-call without depending on SCI synthetic namespaces. The default eval runtime is host JVM eval; SCI is an explicit constrained runtime option.

Runtime helper vars available to code evaluated by a live Repling agent.

These vars delegate through a dynamic live-agent binding, so generated tool
files can use `(require '[repling.agent.runtime :as rt])` and call helpers
like `rt/tool-register!` or `rt/tool-call` without depending on SCI synthetic
namespaces. The default eval runtime is host JVM eval; SCI is an explicit
constrained runtime option.
raw docstring

repling.agent.task

Small virtual-thread helpers used by the agent runtime.

Small virtual-thread helpers used by the agent runtime.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries