Runtime helper vars available to code evaluated by a live Repling agent.
These vars delegate through a dynamic live-agent binding, so generated tool
files can use (require '[repling.agent.runtime :as rt]) and call helpers
like rt/tool-register! or rt/tool-call without depending on SCI synthetic
namespaces. The default eval runtime is host JVM eval; SCI is an explicit
constrained runtime option.
Runtime helper vars available to code evaluated by a live Repling agent. These vars delegate through a dynamic live-agent binding, so generated tool files can use `(require '[repling.agent.runtime :as rt])` and call helpers like `rt/tool-register!` or `rt/tool-call` without depending on SCI synthetic namespaces. The default eval runtime is host JVM eval; SCI is an explicit constrained runtime option.
Small virtual-thread helpers used by the agent runtime.
Small virtual-thread helpers used by the agent runtime.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |