repling.agent.runtime

Runtime helper vars available to code evaluated by a live Repling agent.

These vars delegate through a dynamic live-agent binding, so generated tool files can use (require '[repling.agent.runtime :as rt]) and call helpers like rt/tool-register! or rt/tool-call without depending on SCI synthetic namespaces. The default eval runtime is host JVM eval; SCI is an explicit constrained runtime option.

Runtime helper vars available to code evaluated by a live Repling agent.

These vars delegate through a dynamic live-agent binding, so generated tool
files can use `(require '[repling.agent.runtime :as rt])` and call helpers
like `rt/tool-register!` or `rt/tool-call` without depending on SCI synthetic
namespaces. The default eval runtime is host JVM eval; SCI is an explicit
constrained runtime option.
raw docstring

*operations*clj


compaction-tool-currentclj

(compaction-tool-current & args)

compaction-tool-set!clj

(compaction-tool-set! & args)

prompt-send!clj

(prompt-send! & args)

provider-connect!clj

(provider-connect! & args)

provider-currentclj

(provider-current & args)

provider-disconnect!clj

(provider-disconnect! & args)

session-cancel!clj

(session-cancel! & args)

session-close!clj

(session-close! & args)

session-compact!clj

(session-compact! & args)

session-continue!clj

(session-continue! & args)

session-currentclj

(session-current & args)

session-end!clj

(session-end! & args)

session-historyclj

(session-history & args)

session-readclj

(session-read & args)

sessions-directoryclj

(sessions-directory & args)

sessions-listclj

(sessions-list & args)

tool-callclj

(tool-call & args)

tool-file-load!clj

(tool-file-load! & args)

tool-file-write!clj

(tool-file-write! & args)

tool-lookupclj

(tool-lookup & args)

tool-register!clj

(tool-register! & args)

tool-unregister!clj

(tool-unregister! & args)

tools-directoryclj

(tools-directory & args)

tools-filesclj

(tools-files & args)

tools-listclj

(tools-list & args)

tools-load!clj

(tools-load! & args)

cljdoc builds & hosts documentation for Clojure/Script libraries