Clojure only.

repling.agent.task

Small virtual-thread helpers used by the agent runtime.

Small virtual-thread helpers used by the agent runtime.
raw docstring

callclj

(call f)

Runs f on a bound virtual thread and returns a Clojure-future-like object.

Deref blocks and returns the value, timed deref returns the timeout value on timeout, exceptions rethrow on deref, and the object implements java.util.concurrent.Future for cancellation/status.

Runs `f` on a bound virtual thread and returns a Clojure-future-like object.

Deref blocks and returns the value, timed deref returns the timeout value on
timeout, exceptions rethrow on deref, and the object implements
`java.util.concurrent.Future` for cancellation/status.
raw docstring

futurecljmacro

(future & body)

Runs body on a bound virtual thread and returns a Clojure-future-like object.

Runs `body` on a bound virtual thread and returns a Clojure-future-like
object.
raw docstring

start!clj

(start! f)

Starts f on a bound virtual thread and returns the Thread.

Starts `f` on a bound virtual thread and returns the Thread.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries