Runtime helper vars available to code evaluated by a live Repling agent.
These vars delegate through a dynamic live-agent binding, so generated tool
files can use (require '[repling.agent.runtime :as rt]) and call helpers
like rt/tool-register! or rt/tool-call without depending on SCI synthetic
namespaces. The default eval runtime is host JVM eval; SCI is an explicit
constrained runtime option.
Runtime helper vars available to code evaluated by a live Repling agent. These vars delegate through a dynamic live-agent binding, so generated tool files can use `(require '[repling.agent.runtime :as rt])` and call helpers like `rt/tool-register!` or `rt/tool-call` without depending on SCI synthetic namespaces. The default eval runtime is host JVM eval; SCI is an explicit constrained runtime option.
(compaction-tool-current & args)(compaction-tool-set! & args)(prompt-send! & args)(provider-connect! & args)(provider-current & args)(provider-disconnect! & args)(session-cancel! & args)(session-close! & args)(session-compact! & args)(session-continue! & args)(session-current & args)(session-end! & args)(session-history & args)(session-read & args)(sessions-directory & args)(sessions-list & args)(tool-call & args)(tool-file-load! & args)(tool-file-write! & args)(tool-lookup & args)(tool-register! & args)(tool-unregister! & args)(tools-directory & args)(tools-files & args)(tools-list & args)(tools-load! & args)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |