Small virtual-thread helpers used by the agent runtime.
Small virtual-thread helpers used by the agent runtime.
(call f)Runs f on a bound virtual thread and returns a Clojure-future-like object.
Deref blocks and returns the value, timed deref returns the timeout value on
timeout, exceptions rethrow on deref, and the object implements
java.util.concurrent.Future for cancellation/status.
Runs `f` on a bound virtual thread and returns a Clojure-future-like object. Deref blocks and returns the value, timed deref returns the timeout value on timeout, exceptions rethrow on deref, and the object implements `java.util.concurrent.Future` for cancellation/status.
(future & body)Runs body on a bound virtual thread and returns a Clojure-future-like
object.
Runs `body` on a bound virtual thread and returns a Clojure-future-like object.
(start! f)Starts f on a bound virtual thread and returns the Thread.
Starts `f` on a bound virtual thread and returns the Thread.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |